@@ -22,15 +22,17 @@
 #ifndef _LFN_H
 #define _LFN_H
 
-void lfn_reset( void );
+void lfn_reset(void);
 /* Reset the state of the LFN parser. */
 
-void lfn_add_slot( DIR_ENT *de, loff_t dir_offset );
+void lfn_add_slot(DIR_ENT * de, loff_t dir_offset);
 /* Process a dir slot that is a VFAT LFN entry. */
 
-char *lfn_get( DIR_ENT *de );
+char *lfn_get(DIR_ENT * de, loff_t * lfn_offset);
 /* Retrieve the long name for the proper dir entry. */
 
 void lfn_check_orphaned(void);
 
+void lfn_fix_checksum(loff_t from, loff_t to, const char *short_name);
+
 #endif
